@@ -68,8 +68,6 @@ ipatch_container_get_type(void)
 
         item_type = g_type_register_static(IPATCH_TYPE_ITEM, "IpatchContainer",
                                            &item_info, G_TYPE_FLAG_ABSTRACT);
-
-        _ipatch_container_notify_init();  /* init container add/remove notify system */
     }
 
     return (item_type);
@@ -195,7 +193,13 @@ ipatch_container_get_children_by_type(IpatchContainer *container, GType type)
         if(g_type_is_a(*child_types, type))   /* child type matches type? */
         {
             IPATCH_ITEM_RLOCK(container);
-            ipatch_container_init_iter(container, &iter, *child_types);
+            if(!ipatch_container_init_iter(container, &iter, *child_types))
+            {
+                ipatch_glist_unref_free(list);
+                IPATCH_ITEM_RUNLOCK(container);
+                return (NULL);
+            }
+
             obj = ipatch_iter_first(&iter);
 
             while(obj)		/* add object list to children list */
@@ -228,14 +232,19 @@ const GType *
 ipatch_container_get_child_types(IpatchContainer *container)
 {
     IpatchContainerClass *klass;
-    const GType *types;
 
     g_return_val_if_fail(IPATCH_IS_CONTAINER(container), 0);
 
     klass = IPATCH_CONTAINER_GET_CLASS(container);
-    types = klass->child_types();
 
-    return (types);
+    if(klass->child_types)
+    {
+        return(klass->child_types());
+    }
+    else
+    {
+        return(NULL);
+    }
 }
 
 /**
@@ -349,7 +358,11 @@ ipatch_container_insert(IpatchContainer *container, IpatchItem *item, int pos)
     if(*child_types)	/* matching child type found? */
     {
         IPATCH_ITEM_WLOCK(container);
-        ipatch_container_init_iter(container, &iter, *child_types);
+        if(!ipatch_container_init_iter(container, &iter, *child_types))
+        {
+            IPATCH_ITEM_WUNLOCK(container);
+            return;
+        }
 
         /* if position is less than 1 or off the end, get last object */
         if(pos < 0 || !ipatch_iter_index(&iter, pos))
@@ -440,7 +453,11 @@ ipatch_container_remove(IpatchContainer *container, IpatchItem *item)
         if(g_type_is_a(type, *child_types))   /* item type matches child type? */
         {
             IPATCH_ITEM_WLOCK(container);
-            ipatch_container_init_iter(container, &iter, *child_types);
+            if(!ipatch_container_init_iter(container, &iter, *child_types))
+            {
+                IPATCH_ITEM_WUNLOCK(container);
+                return;
+            }
 
             /* search for @item */
             obj = ipatch_iter_first(&iter);
@@ -530,7 +547,12 @@ ipatch_container_count(IpatchContainer *container, GType type)
         if(g_type_is_a(*child_types, type))   /* child type matches type? */
         {
             IPATCH_ITEM_RLOCK(container);
-            ipatch_container_init_iter(container, &iter, *child_types);
+            if(!ipatch_container_init_iter(container, &iter, *child_types))
+            {
+                IPATCH_ITEM_RUNLOCK(container);
+                return 0;
+            }
+
             count += ipatch_iter_count(&iter);
             IPATCH_ITEM_RUNLOCK(container);
         }
