@@ -65,11 +65,13 @@ typedef struct
 
 /* defined in IpatchItemProp.c */
 extern void _ipatch_item_prop_init(void);
+extern void  _ipatch_item_prop_deinit(void);
 
 /* defined in IpatchBase.c */
 extern GParamSpec *ipatch_base_pspec_changed;
 
-
+static gboolean
+_ipatch_item_hash_free_value(gpointer key, UniqueBag *value, gpointer user_data);
 static void ipatch_item_base_init(IpatchItemClass *klass);
 static void ipatch_item_class_init(IpatchItemClass *klass);
 static void ipatch_item_set_property(GObject *object, guint property_id,
@@ -105,13 +107,43 @@ G_LOCK_DEFINE_STATIC(unique_prop_cache);
 /* cache of IpatchItem unique properties (hash: GType => UniqueBag) */
 static GHashTable *unique_prop_cache = NULL;
 
-/* a dummy bag pointer used to indicate that an item type has no unique props */
-static UniqueBag no_unique_props;
-
 /* store title property GParamSpec as a convenience to derived types */
 /* Useful when libinstpatch library is used as a static library. */
 GParamSpec *ipatch_item_pspec_title = NULL;
 
+/* ----- Initialization/deinitialization of property change callback system -*/
+/* Initialization */
+void _ipatch_item_init(void)
+{
+    /* cache of IpatchItem unique properties (hash: GType => UniqueBag) */
+    unique_prop_cache = g_hash_table_new (NULL, NULL);
+
+    /* Initialize property change callback system */
+    _ipatch_item_prop_init();
+}
+
+/* Free property change callback system */
+void _ipatch_item_deinit(void)
+{
+    /* free property change callback system */
+    _ipatch_item_prop_deinit();
+    g_hash_table_foreach_remove(unique_prop_cache,
+                               (GHRFunc)_ipatch_item_hash_free_value,
+                                NULL);
+    g_hash_table_destroy(unique_prop_cache);
+}
+
+/* free hash value entry */
+static gboolean
+_ipatch_item_hash_free_value(gpointer key, UniqueBag *value, gpointer user_data)
+{
+    g_free(value->pspecs);
+    g_free(value);
+    return TRUE;
+}
+
+/* ----- IpatchItem object functions  ---------------------------------------*/
+
 /*
  Getter function returning title property GParamSpec as a convenience to derived type.
  Useful when libinstpatch library is used as a shared library linked at load time.
@@ -140,11 +172,6 @@ ipatch_item_get_type(void)
 
         item_type = g_type_register_static(G_TYPE_OBJECT, "IpatchItem",
                                            &item_info, G_TYPE_FLAG_ABSTRACT);
-
-        /* create unique property cache (elements are never removed) */
-        unique_prop_cache = g_hash_table_new(NULL, NULL);
-
-        _ipatch_item_prop_init();	/* Initialize property change callback system */
     }
 
     return (item_type);
@@ -249,7 +276,7 @@ ipatch_item_class_init(IpatchItemClass *klass)
     g_object_class_install_property(obj_class, PROP_FLAGS,
                                     g_param_spec_uint("flags", _("Flags"), _("Flags"),
                                             0, G_MAXUINT, 0,
-                                            G_PARAM_READABLE | IPATCH_PARAM_HIDE
+                                            G_PARAM_READWRITE | IPATCH_PARAM_HIDE
                                             | IPATCH_PARAM_NO_SAVE_CHANGE
                                             | IPATCH_PARAM_NO_SAVE));
     g_object_class_install_property(obj_class, PROP_PARENT,
@@ -558,7 +585,11 @@ ipatch_item_recursive_base_set(IpatchContainer *container, SetParentBag *bag)
     while(*types)		/* loop over list types */
     {
         /* initialize iterator to child list */
-        ipatch_container_init_iter(container, &iter, *types);
+        if(!ipatch_container_init_iter(container, &iter, *types))
+        {
+            return;
+        }
+
         child = ipatch_iter_first(&iter);
 
         while(child)		/* loop over child list */
@@ -642,7 +673,11 @@ ipatch_item_recursive_base_unset(IpatchContainer *container)
     while(*types)		/* loop over list types */
     {
         /* initialize iterator to child list */
-        ipatch_container_init_iter(container, &iter, *types);
+        if(!ipatch_container_init_iter(container, &iter, *types))
+        {
+            return;
+        }
+
         child = ipatch_iter_first(&iter);
 
         while(child)		/* loop over child list */
@@ -1136,7 +1171,6 @@ ipatch_item_copy_link_func(IpatchItem *dest, IpatchItem *src,
 
     g_return_if_fail(IPATCH_IS_ITEM(dest));
     g_return_if_fail(IPATCH_IS_ITEM(src));
-    g_return_if_fail(link_func != NULL);
 
     dest_type = G_OBJECT_TYPE(dest);
     src_type = G_OBJECT_TYPE(src);
@@ -1619,15 +1653,16 @@ item_lookup_unique_bag(GType type)
 
     G_LOCK(unique_prop_cache);
 
-    unique = g_hash_table_lookup(unique_prop_cache, GUINT_TO_POINTER(type));
-
-    if(!unique)			/* has not been cached yet? */
+    /* has not been cached yet? */
+    if(! g_hash_table_lookup_extended(unique_prop_cache,
+                                      GUINT_TO_POINTER (type),
+                                      NULL, (gpointer *)&unique))
     {
-        klass = g_type_class_ref(type);
+        klass = g_type_class_ref(type); /* ++ref */
         g_return_val_if_fail(klass != NULL, NULL);
 
         /* get property list and add unique properties to speclist */
-        pspecs = g_object_class_list_properties(klass, &n_props);
+        pspecs = g_object_class_list_properties(klass, &n_props); /* alloc */
 
         for(i = 0, count = 0; i < n_props; i++)
         {
@@ -1642,7 +1677,8 @@ item_lookup_unique_bag(GType type)
             }
         }
 
-        g_free(pspecs);
+        g_free(pspecs); /* free */
+        g_type_class_unref(klass); /* --ref */
 
         if(speclist)	/* any unique properties? */
         {
@@ -1679,7 +1715,7 @@ item_lookup_unique_bag(GType type)
         }
         else
         {
-            unique = &no_unique_props;    /* indicate no unique properties */
+            unique = unique = NULL;    /* indicate no unique properties */
         }
 
         g_hash_table_insert(unique_prop_cache, GUINT_TO_POINTER(type), unique);
@@ -1687,11 +1723,6 @@ item_lookup_unique_bag(GType type)
 
     G_UNLOCK(unique_prop_cache);
 
-    if(unique == &no_unique_props)	/* no unique properties? */
-    {
-        unique = NULL;
-    }
-
     return (unique);
 }
 
